# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['KeyPairArgs', 'KeyPair']

@pulumi.input_type
class KeyPairArgs:
    def __init__(__self__, *,
                 key_pair_name: pulumi.Input[builtins.str],
                 public_key_body: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a KeyPair resource.
        :param pulumi.Input[builtins.str] key_pair_name: ADB key pair name.
        :param pulumi.Input[builtins.str] public_key_body: The public key of the key pair.
        """
        pulumi.set(__self__, "key_pair_name", key_pair_name)
        if public_key_body is not None:
            pulumi.set(__self__, "public_key_body", public_key_body)

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> pulumi.Input[builtins.str]:
        """
        ADB key pair name.
        """
        return pulumi.get(self, "key_pair_name")

    @key_pair_name.setter
    def key_pair_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "key_pair_name", value)

    @property
    @pulumi.getter(name="publicKeyBody")
    def public_key_body(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The public key of the key pair.
        """
        return pulumi.get(self, "public_key_body")

    @public_key_body.setter
    def public_key_body(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "public_key_body", value)


@pulumi.input_type
class _KeyPairState:
    def __init__(__self__, *,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 public_key_body: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering KeyPair resources.
        :param pulumi.Input[builtins.str] key_pair_name: ADB key pair name.
        :param pulumi.Input[builtins.str] public_key_body: The public key of the key pair.
        """
        if key_pair_name is not None:
            pulumi.set(__self__, "key_pair_name", key_pair_name)
        if public_key_body is not None:
            pulumi.set(__self__, "public_key_body", public_key_body)

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ADB key pair name.
        """
        return pulumi.get(self, "key_pair_name")

    @key_pair_name.setter
    def key_pair_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key_pair_name", value)

    @property
    @pulumi.getter(name="publicKeyBody")
    def public_key_body(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The public key of the key pair.
        """
        return pulumi.get(self, "public_key_body")

    @public_key_body.setter
    def public_key_body(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "public_key_body", value)


@pulumi.type_token("alicloud:cloudphone/keyPair:KeyPair")
class KeyPair(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 public_key_body: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Cloud Phone Key Pair resource.

        Cloud Phone KeyPair.

        For information about Cloud Phone Key Pair and how to use it, see [What is Key Pair](https://next.api.alibabacloud.com/document/eds-aic/2023-09-30/CreateKeyPair).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        defaultj_z1gi0 = alicloud.cloudphone.Policy("defaultjZ1gi0")
        default_yh_ml_to = alicloud.cloudphoneinstance.Group("defaultYHMlTO",
            instance_group_spec="acp.basic.small",
            policy_group_id=defaultj_z1gi0.id,
            instance_group_name="AutoCreateGroupName",
            period=1,
            number_of_instances=1,
            charge_type="PostPaid",
            image_id="imgc-075cllfeuazh03tg9",
            period_unit="Hour",
            auto_renew=False,
            amount=1,
            auto_pay=False,
            gpu_acceleration=False)
        defaulthd_bep1 = alicloud.cloudphoneinstance.CloudPhoneInstance("defaulthdBep1",
            android_instance_group_id=default_yh_ml_to.id,
            android_instance_name="CreateInstanceName")
        default = alicloud.cloudphone.KeyPair("default",
            key_pair_name="example",
            public_key_body="QAAAAH0o+PMrbz9ZlxaNMYlk1rJkN4JXqwSUVYW5YzMW3fWJ7At1XO40GYDEFL43fLob52pmRxRDuRoGAELmS1AyzqUle2v9yGKFziqS/vK/4vM4MW/ppnTmvh9zPXir0fB/uwXS4iS6xt0gmvprgyRNs7hgXtBK9ASiGuPCv47aRJqh9mYzq2pe2rgb+K0OU5/nQXwWKSxYsv+w3KWPshpwx8iF/JWvjixILJ5gygndd+1HyE8jrLVmvm/OitNaMgkolY1bvmRVVKLmzde7FtXw0s4TVfYUvF385gwlrOulKcL7UuMHV87MV/tcvEA0Gg88JrKgI5LmvQ8BDkrfoSi+bchk1KTAqJ8YMvL2pOogXbBoONeJS176zLYpLHmONtIDQFz/gEqAjGQVW+j4J+1w8oWrn8EjtcDe2kY34s3PDLioK3BN9CIBBQur+SH25R0RnEqD0YPFT7/ym0LomtPOS0t72n5JejBTfWaXiqb/I4f2Ypy1PA6fV5UUFIHODpNtuS4g2HKKqDS/sgYRBA2gpN2MmqeqgsQmSy+EljHdUe4KDVqAZ/qxLqnbp47BGHw2xjuZ60nXAoRecWCg2GDbx13ga4dKUQY+ER8Jruz7ILK4MRB7E4SjSUVmgcdh534c51BYIdI2HkQwQU2dgyJyQme9sDQxxGHpYKFQlFSyXUeOSjXLtQEAAQA= qiaozhou_15694163938@h2sqyfpc71g1t2w")
        ```

        ## Import

        Cloud Phone Key Pair can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudphone/keyPair:KeyPair example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] key_pair_name: ADB key pair name.
        :param pulumi.Input[builtins.str] public_key_body: The public key of the key pair.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KeyPairArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Phone Key Pair resource.

        Cloud Phone KeyPair.

        For information about Cloud Phone Key Pair and how to use it, see [What is Key Pair](https://next.api.alibabacloud.com/document/eds-aic/2023-09-30/CreateKeyPair).

        > **NOTE:** Available since v1.243.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        defaultj_z1gi0 = alicloud.cloudphone.Policy("defaultjZ1gi0")
        default_yh_ml_to = alicloud.cloudphoneinstance.Group("defaultYHMlTO",
            instance_group_spec="acp.basic.small",
            policy_group_id=defaultj_z1gi0.id,
            instance_group_name="AutoCreateGroupName",
            period=1,
            number_of_instances=1,
            charge_type="PostPaid",
            image_id="imgc-075cllfeuazh03tg9",
            period_unit="Hour",
            auto_renew=False,
            amount=1,
            auto_pay=False,
            gpu_acceleration=False)
        defaulthd_bep1 = alicloud.cloudphoneinstance.CloudPhoneInstance("defaulthdBep1",
            android_instance_group_id=default_yh_ml_to.id,
            android_instance_name="CreateInstanceName")
        default = alicloud.cloudphone.KeyPair("default",
            key_pair_name="example",
            public_key_body="QAAAAH0o+PMrbz9ZlxaNMYlk1rJkN4JXqwSUVYW5YzMW3fWJ7At1XO40GYDEFL43fLob52pmRxRDuRoGAELmS1AyzqUle2v9yGKFziqS/vK/4vM4MW/ppnTmvh9zPXir0fB/uwXS4iS6xt0gmvprgyRNs7hgXtBK9ASiGuPCv47aRJqh9mYzq2pe2rgb+K0OU5/nQXwWKSxYsv+w3KWPshpwx8iF/JWvjixILJ5gygndd+1HyE8jrLVmvm/OitNaMgkolY1bvmRVVKLmzde7FtXw0s4TVfYUvF385gwlrOulKcL7UuMHV87MV/tcvEA0Gg88JrKgI5LmvQ8BDkrfoSi+bchk1KTAqJ8YMvL2pOogXbBoONeJS176zLYpLHmONtIDQFz/gEqAjGQVW+j4J+1w8oWrn8EjtcDe2kY34s3PDLioK3BN9CIBBQur+SH25R0RnEqD0YPFT7/ym0LomtPOS0t72n5JejBTfWaXiqb/I4f2Ypy1PA6fV5UUFIHODpNtuS4g2HKKqDS/sgYRBA2gpN2MmqeqgsQmSy+EljHdUe4KDVqAZ/qxLqnbp47BGHw2xjuZ60nXAoRecWCg2GDbx13ga4dKUQY+ER8Jruz7ILK4MRB7E4SjSUVmgcdh534c51BYIdI2HkQwQU2dgyJyQme9sDQxxGHpYKFQlFSyXUeOSjXLtQEAAQA= qiaozhou_15694163938@h2sqyfpc71g1t2w")
        ```

        ## Import

        Cloud Phone Key Pair can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudphone/keyPair:KeyPair example <id>
        ```

        :param str resource_name: The name of the resource.
        :param KeyPairArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KeyPairArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
                 public_key_body: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KeyPairArgs.__new__(KeyPairArgs)

            if key_pair_name is None and not opts.urn:
                raise TypeError("Missing required property 'key_pair_name'")
            __props__.__dict__["key_pair_name"] = key_pair_name
            __props__.__dict__["public_key_body"] = public_key_body
        super(KeyPair, __self__).__init__(
            'alicloud:cloudphone/keyPair:KeyPair',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            key_pair_name: Optional[pulumi.Input[builtins.str]] = None,
            public_key_body: Optional[pulumi.Input[builtins.str]] = None) -> 'KeyPair':
        """
        Get an existing KeyPair resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] key_pair_name: ADB key pair name.
        :param pulumi.Input[builtins.str] public_key_body: The public key of the key pair.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KeyPairState.__new__(_KeyPairState)

        __props__.__dict__["key_pair_name"] = key_pair_name
        __props__.__dict__["public_key_body"] = public_key_body
        return KeyPair(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> pulumi.Output[builtins.str]:
        """
        ADB key pair name.
        """
        return pulumi.get(self, "key_pair_name")

    @property
    @pulumi.getter(name="publicKeyBody")
    def public_key_body(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The public key of the key pair.
        """
        return pulumi.get(self, "public_key_body")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstancesResult',
    'AwaitableGetInstancesResult',
    'get_instances',
    'get_instances_output',
]

@pulumi.output_type
class GetInstancesResult:
    """
    A collection of values returned by getInstances.
    """
    def __init__(__self__, description_regex=None, descriptions=None, id=None, ids=None, instances=None, name_regex=None, output_file=None):
        if description_regex and not isinstance(description_regex, str):
            raise TypeError("Expected argument 'description_regex' to be a str")
        pulumi.set(__self__, "description_regex", description_regex)
        if descriptions and not isinstance(descriptions, list):
            raise TypeError("Expected argument 'descriptions' to be a list")
        pulumi.set(__self__, "descriptions", descriptions)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        pulumi.set(__self__, "instances", instances)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter(name="descriptionRegex")
    def description_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "description_regex")

    @property
    @pulumi.getter
    def descriptions(self) -> Sequence[builtins.str]:
        """
        A list of DRDS descriptions.
        """
        return pulumi.get(self, "descriptions")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        """
        A list of DRDS instance IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def instances(self) -> Sequence['outputs.GetInstancesInstanceResult']:
        """
        A list of DRDS instances.
        """
        return pulumi.get(self, "instances")

    @property
    @pulumi.getter(name="nameRegex")
    @_utilities.deprecated("""Field 'name_regex' is deprecated and will be removed in a future release. Please use 'description_regex' instead.""")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")


class AwaitableGetInstancesResult(GetInstancesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstancesResult(
            description_regex=self.description_regex,
            descriptions=self.descriptions,
            id=self.id,
            ids=self.ids,
            instances=self.instances,
            name_regex=self.name_regex,
            output_file=self.output_file)


def get_instances(description_regex: Optional[builtins.str] = None,
                  ids: Optional[Sequence[builtins.str]] = None,
                  name_regex: Optional[builtins.str] = None,
                  output_file: Optional[builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstancesResult:
    """
    The `drds.Instance` data source provides a collection of DRDS instances available in Alibaba Cloud account.
    Filters support regular expression for the instance name, searches by tags, and other filters which are listed below.

    > **NOTE:** Available in 1.35.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    drds_instances_ds = alicloud.drds.get_instances(name_regex="drds-\\\\d+",
       ids=["drdsabc123456"])
    pulumi.export("firstDbInstanceId", drds_instances_ds.instances[0].id)
    ```


    :param builtins.str description_regex: A regex string to filter results by instance description.
    :param Sequence[builtins.str] ids: A list of DRDS instance IDs.
    :param builtins.str name_regex: A regex string to filter results by instance description. It is deprecated since v1.91.0 and will be removed in a future release, please use 'description_regex' instead.
    """
    __args__ = dict()
    __args__['descriptionRegex'] = description_regex
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:drds/getInstances:getInstances', __args__, opts=opts, typ=GetInstancesResult).value

    return AwaitableGetInstancesResult(
        description_regex=pulumi.get(__ret__, 'description_regex'),
        descriptions=pulumi.get(__ret__, 'descriptions'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        instances=pulumi.get(__ret__, 'instances'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_instances_output(description_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                         name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstancesResult]:
    """
    The `drds.Instance` data source provides a collection of DRDS instances available in Alibaba Cloud account.
    Filters support regular expression for the instance name, searches by tags, and other filters which are listed below.

    > **NOTE:** Available in 1.35.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    drds_instances_ds = alicloud.drds.get_instances(name_regex="drds-\\\\d+",
       ids=["drdsabc123456"])
    pulumi.export("firstDbInstanceId", drds_instances_ds.instances[0].id)
    ```


    :param builtins.str description_regex: A regex string to filter results by instance description.
    :param Sequence[builtins.str] ids: A list of DRDS instance IDs.
    :param builtins.str name_regex: A regex string to filter results by instance description. It is deprecated since v1.91.0 and will be removed in a future release, please use 'description_regex' instead.
    """
    __args__ = dict()
    __args__['descriptionRegex'] = description_regex
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:drds/getInstances:getInstances', __args__, opts=opts, typ=GetInstancesResult)
    return __ret__.apply(lambda __response__: GetInstancesResult(
        description_regex=pulumi.get(__response__, 'description_regex'),
        descriptions=pulumi.get(__response__, 'descriptions'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        instances=pulumi.get(__response__, 'instances'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        output_file=pulumi.get(__response__, 'output_file')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .api_destination import *
from .connection import *
from .event_bus import *
from .event_source import *
from .get_event_buses import *
from .get_event_sources import *
from .get_rules import *
from .get_service import *
from .rule import *
from .service_linked_role import *
from .slr import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PublicNetworkArgs', 'PublicNetwork']

@pulumi.input_type
class PublicNetworkArgs:
    def __init__(__self__, *,
                 engine_type: pulumi.Input[builtins.str],
                 instance_id: pulumi.Input[builtins.str],
                 enable_public_network: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a PublicNetwork resource.
        :param pulumi.Input[builtins.str] engine_type: Engine type, value:
        :param pulumi.Input[builtins.str] instance_id: Instance ID
        :param pulumi.Input[builtins.int] enable_public_network: Open or close the public connection. Value:
        """
        pulumi.set(__self__, "engine_type", engine_type)
        pulumi.set(__self__, "instance_id", instance_id)
        if enable_public_network is not None:
            pulumi.set(__self__, "enable_public_network", enable_public_network)

    @property
    @pulumi.getter(name="engineType")
    def engine_type(self) -> pulumi.Input[builtins.str]:
        """
        Engine type, value:
        """
        return pulumi.get(self, "engine_type")

    @engine_type.setter
    def engine_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "engine_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        Instance ID
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="enablePublicNetwork")
    def enable_public_network(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Open or close the public connection. Value:
        """
        return pulumi.get(self, "enable_public_network")

    @enable_public_network.setter
    def enable_public_network(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "enable_public_network", value)


@pulumi.input_type
class _PublicNetworkState:
    def __init__(__self__, *,
                 enable_public_network: Optional[pulumi.Input[builtins.int]] = None,
                 engine_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering PublicNetwork resources.
        :param pulumi.Input[builtins.int] enable_public_network: Open or close the public connection. Value:
        :param pulumi.Input[builtins.str] engine_type: Engine type, value:
        :param pulumi.Input[builtins.str] instance_id: Instance ID
        :param pulumi.Input[builtins.str] status: Instance status, returns:_EXPANDING`: Capacity-based cloud storage is being expanded._version_transing`: The minor version is being upgraded._CHANGING`: The specification is being upgraded or downgraded._SWITCHING`:SSL is being changed._OPENING`: The data subscription function is being activated._TRANSFER`: migrates data to the database._CREATING`: in the production disaster recovery instance._RECOVERING`: The backup is being restored._IMPORTING`: Data is being imported._MODIFYING`: The network is being changed._SWITCHING`: The internal network and the external network are being switched._CREATING`: creates a network link._DELETING`: deletes a network link.
        """
        if enable_public_network is not None:
            pulumi.set(__self__, "enable_public_network", enable_public_network)
        if engine_type is not None:
            pulumi.set(__self__, "engine_type", engine_type)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="enablePublicNetwork")
    def enable_public_network(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Open or close the public connection. Value:
        """
        return pulumi.get(self, "enable_public_network")

    @enable_public_network.setter
    def enable_public_network(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "enable_public_network", value)

    @property
    @pulumi.getter(name="engineType")
    def engine_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Engine type, value:
        """
        return pulumi.get(self, "engine_type")

    @engine_type.setter
    def engine_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "engine_type", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Instance ID
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Instance status, returns:_EXPANDING`: Capacity-based cloud storage is being expanded._version_transing`: The minor version is being upgraded._CHANGING`: The specification is being upgraded or downgraded._SWITCHING`:SSL is being changed._OPENING`: The data subscription function is being activated._TRANSFER`: migrates data to the database._CREATING`: in the production disaster recovery instance._RECOVERING`: The backup is being restored._IMPORTING`: Data is being imported._MODIFYING`: The network is being changed._SWITCHING`: The internal network and the external network are being switched._CREATING`: creates a network link._DELETING`: deletes a network link.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("alicloud:lindorm/publicNetwork:PublicNetwork")
class PublicNetwork(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_public_network: Optional[pulumi.Input[builtins.int]] = None,
                 engine_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        Lindorm Public Network can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:lindorm/publicNetwork:PublicNetwork example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] enable_public_network: Open or close the public connection. Value:
        :param pulumi.Input[builtins.str] engine_type: Engine type, value:
        :param pulumi.Input[builtins.str] instance_id: Instance ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PublicNetworkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Lindorm Public Network can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:lindorm/publicNetwork:PublicNetwork example <id>
        ```

        :param str resource_name: The name of the resource.
        :param PublicNetworkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PublicNetworkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enable_public_network: Optional[pulumi.Input[builtins.int]] = None,
                 engine_type: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PublicNetworkArgs.__new__(PublicNetworkArgs)

            __props__.__dict__["enable_public_network"] = enable_public_network
            if engine_type is None and not opts.urn:
                raise TypeError("Missing required property 'engine_type'")
            __props__.__dict__["engine_type"] = engine_type
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["status"] = None
        super(PublicNetwork, __self__).__init__(
            'alicloud:lindorm/publicNetwork:PublicNetwork',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enable_public_network: Optional[pulumi.Input[builtins.int]] = None,
            engine_type: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'PublicNetwork':
        """
        Get an existing PublicNetwork resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] enable_public_network: Open or close the public connection. Value:
        :param pulumi.Input[builtins.str] engine_type: Engine type, value:
        :param pulumi.Input[builtins.str] instance_id: Instance ID
        :param pulumi.Input[builtins.str] status: Instance status, returns:_EXPANDING`: Capacity-based cloud storage is being expanded._version_transing`: The minor version is being upgraded._CHANGING`: The specification is being upgraded or downgraded._SWITCHING`:SSL is being changed._OPENING`: The data subscription function is being activated._TRANSFER`: migrates data to the database._CREATING`: in the production disaster recovery instance._RECOVERING`: The backup is being restored._IMPORTING`: Data is being imported._MODIFYING`: The network is being changed._SWITCHING`: The internal network and the external network are being switched._CREATING`: creates a network link._DELETING`: deletes a network link.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PublicNetworkState.__new__(_PublicNetworkState)

        __props__.__dict__["enable_public_network"] = enable_public_network
        __props__.__dict__["engine_type"] = engine_type
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["status"] = status
        return PublicNetwork(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="enablePublicNetwork")
    def enable_public_network(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Open or close the public connection. Value:
        """
        return pulumi.get(self, "enable_public_network")

    @property
    @pulumi.getter(name="engineType")
    def engine_type(self) -> pulumi.Output[builtins.str]:
        """
        Engine type, value:
        """
        return pulumi.get(self, "engine_type")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        Instance ID
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Instance status, returns:_EXPANDING`: Capacity-based cloud storage is being expanded._version_transing`: The minor version is being upgraded._CHANGING`: The specification is being upgraded or downgraded._SWITCHING`:SSL is being changed._OPENING`: The data subscription function is being activated._TRANSFER`: migrates data to the database._CREATING`: in the production disaster recovery instance._RECOVERING`: The backup is being restored._IMPORTING`: Data is being imported._MODIFYING`: The network is being changed._SWITCHING`: The internal network and the external network are being switched._CREATING`: creates a network link._DELETING`: deletes a network link.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['TransitRouteTableAggregationArgs', 'TransitRouteTableAggregation']

@pulumi.input_type
class TransitRouteTableAggregationArgs:
    def __init__(__self__, *,
                 transit_route_table_aggregation_cidr: pulumi.Input[builtins.str],
                 transit_route_table_id: pulumi.Input[builtins.str],
                 transit_route_table_aggregation_description: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_scope: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_scope_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a TransitRouteTableAggregation resource.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_cidr: The destination CIDR block of the aggregate route.
               
               > **NOTE:**   The following CIDR blocks are not supported:
               
               > **NOTE:** *   CIDR blocks that start with 0 or 100.64.
               
               > **NOTE:** *   Multicast CIDR blocks, including 224.0.0.1 to 239.255.255.254.
        :param pulumi.Input[builtins.str] transit_route_table_id: The list of route table IDs of the Enterprise Edition transit router.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_description: The list of propagation ranges of the aggregation route.
               
               > **NOTE:**   You must specify at least one of the following attributes: Aggregation Scope and Aggregate Scope List. We recommend that you specify the latter. The elements in the two attributes cannot be duplicate.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_name: The name of the aggregate route.
               The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_scope: The scope of networks that you want to advertise the aggregate route.
               The valid value is `VPC`, which indicates that the aggregate route is advertised to all VPCs that have associated forwarding correlation with the Enterprise Edition transit router and have route synchronization enabled.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] transit_route_table_aggregation_scope_lists: Aggregation Route Scopes
        """
        pulumi.set(__self__, "transit_route_table_aggregation_cidr", transit_route_table_aggregation_cidr)
        pulumi.set(__self__, "transit_route_table_id", transit_route_table_id)
        if transit_route_table_aggregation_description is not None:
            pulumi.set(__self__, "transit_route_table_aggregation_description", transit_route_table_aggregation_description)
        if transit_route_table_aggregation_name is not None:
            pulumi.set(__self__, "transit_route_table_aggregation_name", transit_route_table_aggregation_name)
        if transit_route_table_aggregation_scope is not None:
            pulumi.set(__self__, "transit_route_table_aggregation_scope", transit_route_table_aggregation_scope)
        if transit_route_table_aggregation_scope_lists is not None:
            pulumi.set(__self__, "transit_route_table_aggregation_scope_lists", transit_route_table_aggregation_scope_lists)

    @property
    @pulumi.getter(name="transitRouteTableAggregationCidr")
    def transit_route_table_aggregation_cidr(self) -> pulumi.Input[builtins.str]:
        """
        The destination CIDR block of the aggregate route.

        > **NOTE:**   The following CIDR blocks are not supported:

        > **NOTE:** *   CIDR blocks that start with 0 or 100.64.

        > **NOTE:** *   Multicast CIDR blocks, including 224.0.0.1 to 239.255.255.254.
        """
        return pulumi.get(self, "transit_route_table_aggregation_cidr")

    @transit_route_table_aggregation_cidr.setter
    def transit_route_table_aggregation_cidr(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "transit_route_table_aggregation_cidr", value)

    @property
    @pulumi.getter(name="transitRouteTableId")
    def transit_route_table_id(self) -> pulumi.Input[builtins.str]:
        """
        The list of route table IDs of the Enterprise Edition transit router.
        """
        return pulumi.get(self, "transit_route_table_id")

    @transit_route_table_id.setter
    def transit_route_table_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "transit_route_table_id", value)

    @property
    @pulumi.getter(name="transitRouteTableAggregationDescription")
    def transit_route_table_aggregation_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The list of propagation ranges of the aggregation route.

        > **NOTE:**   You must specify at least one of the following attributes: Aggregation Scope and Aggregate Scope List. We recommend that you specify the latter. The elements in the two attributes cannot be duplicate.
        """
        return pulumi.get(self, "transit_route_table_aggregation_description")

    @transit_route_table_aggregation_description.setter
    def transit_route_table_aggregation_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_route_table_aggregation_description", value)

    @property
    @pulumi.getter(name="transitRouteTableAggregationName")
    def transit_route_table_aggregation_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the aggregate route.
        The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        """
        return pulumi.get(self, "transit_route_table_aggregation_name")

    @transit_route_table_aggregation_name.setter
    def transit_route_table_aggregation_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_route_table_aggregation_name", value)

    @property
    @pulumi.getter(name="transitRouteTableAggregationScope")
    def transit_route_table_aggregation_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The scope of networks that you want to advertise the aggregate route.
        The valid value is `VPC`, which indicates that the aggregate route is advertised to all VPCs that have associated forwarding correlation with the Enterprise Edition transit router and have route synchronization enabled.
        """
        return pulumi.get(self, "transit_route_table_aggregation_scope")

    @transit_route_table_aggregation_scope.setter
    def transit_route_table_aggregation_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_route_table_aggregation_scope", value)

    @property
    @pulumi.getter(name="transitRouteTableAggregationScopeLists")
    def transit_route_table_aggregation_scope_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Aggregation Route Scopes
        """
        return pulumi.get(self, "transit_route_table_aggregation_scope_lists")

    @transit_route_table_aggregation_scope_lists.setter
    def transit_route_table_aggregation_scope_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "transit_route_table_aggregation_scope_lists", value)


@pulumi.input_type
class _TransitRouteTableAggregationState:
    def __init__(__self__, *,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_cidr: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_description: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_scope: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_scope_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 transit_route_table_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering TransitRouteTableAggregation resources.
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_cidr: The destination CIDR block of the aggregate route.
               
               > **NOTE:**   The following CIDR blocks are not supported:
               
               > **NOTE:** *   CIDR blocks that start with 0 or 100.64.
               
               > **NOTE:** *   Multicast CIDR blocks, including 224.0.0.1 to 239.255.255.254.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_description: The list of propagation ranges of the aggregation route.
               
               > **NOTE:**   You must specify at least one of the following attributes: Aggregation Scope and Aggregate Scope List. We recommend that you specify the latter. The elements in the two attributes cannot be duplicate.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_name: The name of the aggregate route.
               The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_scope: The scope of networks that you want to advertise the aggregate route.
               The valid value is `VPC`, which indicates that the aggregate route is advertised to all VPCs that have associated forwarding correlation with the Enterprise Edition transit router and have route synchronization enabled.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] transit_route_table_aggregation_scope_lists: Aggregation Route Scopes
        :param pulumi.Input[builtins.str] transit_route_table_id: The list of route table IDs of the Enterprise Edition transit router.
        """
        if status is not None:
            pulumi.set(__self__, "status", status)
        if transit_route_table_aggregation_cidr is not None:
            pulumi.set(__self__, "transit_route_table_aggregation_cidr", transit_route_table_aggregation_cidr)
        if transit_route_table_aggregation_description is not None:
            pulumi.set(__self__, "transit_route_table_aggregation_description", transit_route_table_aggregation_description)
        if transit_route_table_aggregation_name is not None:
            pulumi.set(__self__, "transit_route_table_aggregation_name", transit_route_table_aggregation_name)
        if transit_route_table_aggregation_scope is not None:
            pulumi.set(__self__, "transit_route_table_aggregation_scope", transit_route_table_aggregation_scope)
        if transit_route_table_aggregation_scope_lists is not None:
            pulumi.set(__self__, "transit_route_table_aggregation_scope_lists", transit_route_table_aggregation_scope_lists)
        if transit_route_table_id is not None:
            pulumi.set(__self__, "transit_route_table_id", transit_route_table_id)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="transitRouteTableAggregationCidr")
    def transit_route_table_aggregation_cidr(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The destination CIDR block of the aggregate route.

        > **NOTE:**   The following CIDR blocks are not supported:

        > **NOTE:** *   CIDR blocks that start with 0 or 100.64.

        > **NOTE:** *   Multicast CIDR blocks, including 224.0.0.1 to 239.255.255.254.
        """
        return pulumi.get(self, "transit_route_table_aggregation_cidr")

    @transit_route_table_aggregation_cidr.setter
    def transit_route_table_aggregation_cidr(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_route_table_aggregation_cidr", value)

    @property
    @pulumi.getter(name="transitRouteTableAggregationDescription")
    def transit_route_table_aggregation_description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The list of propagation ranges of the aggregation route.

        > **NOTE:**   You must specify at least one of the following attributes: Aggregation Scope and Aggregate Scope List. We recommend that you specify the latter. The elements in the two attributes cannot be duplicate.
        """
        return pulumi.get(self, "transit_route_table_aggregation_description")

    @transit_route_table_aggregation_description.setter
    def transit_route_table_aggregation_description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_route_table_aggregation_description", value)

    @property
    @pulumi.getter(name="transitRouteTableAggregationName")
    def transit_route_table_aggregation_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the aggregate route.
        The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        """
        return pulumi.get(self, "transit_route_table_aggregation_name")

    @transit_route_table_aggregation_name.setter
    def transit_route_table_aggregation_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_route_table_aggregation_name", value)

    @property
    @pulumi.getter(name="transitRouteTableAggregationScope")
    def transit_route_table_aggregation_scope(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The scope of networks that you want to advertise the aggregate route.
        The valid value is `VPC`, which indicates that the aggregate route is advertised to all VPCs that have associated forwarding correlation with the Enterprise Edition transit router and have route synchronization enabled.
        """
        return pulumi.get(self, "transit_route_table_aggregation_scope")

    @transit_route_table_aggregation_scope.setter
    def transit_route_table_aggregation_scope(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_route_table_aggregation_scope", value)

    @property
    @pulumi.getter(name="transitRouteTableAggregationScopeLists")
    def transit_route_table_aggregation_scope_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Aggregation Route Scopes
        """
        return pulumi.get(self, "transit_route_table_aggregation_scope_lists")

    @transit_route_table_aggregation_scope_lists.setter
    def transit_route_table_aggregation_scope_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "transit_route_table_aggregation_scope_lists", value)

    @property
    @pulumi.getter(name="transitRouteTableId")
    def transit_route_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The list of route table IDs of the Enterprise Edition transit router.
        """
        return pulumi.get(self, "transit_route_table_id")

    @transit_route_table_id.setter
    def transit_route_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_route_table_id", value)


@pulumi.type_token("alicloud:cen/transitRouteTableAggregation:TransitRouteTableAggregation")
class TransitRouteTableAggregation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 transit_route_table_aggregation_cidr: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_description: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_scope: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_scope_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 transit_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Cloud Enterprise Network (CEN) Transit Route Table Aggregation resource.

        For information about Cloud Enterprise Network (CEN) Transit Route Table Aggregation and how to use it, see [What is Transit Route Table Aggregation](https://next.api.alibabacloud.com/document/Cbn/2017-09-12/CreateTransitRouteTableAggregation).

        > **NOTE:** Available since v1.245.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.cen.Instance("example",
            cen_instance_name="tf_example",
            description="an example for cen")
        example_transit_router = alicloud.cen.TransitRouter("example",
            transit_router_name="tf_example",
            cen_id=example.id)
        example_transit_router_route_table = alicloud.cen.TransitRouterRouteTable("example", transit_router_id=example_transit_router.transit_router_id)
        example_transit_route_table_aggregation = alicloud.cen.TransitRouteTableAggregation("example",
            transit_route_table_id=example_transit_router_route_table.transit_router_route_table_id,
            transit_route_table_aggregation_cidr="10.0.0.0/8",
            transit_route_table_aggregation_scope="VPC",
            transit_route_table_aggregation_name="tf_example",
            transit_route_table_aggregation_description="tf_example")
        ```

        ## Import

        Cloud Enterprise Network (CEN) Transit Route Table Aggregation can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/transitRouteTableAggregation:TransitRouteTableAggregation example <transit_route_table_id>#<transit_route_table_aggregation_cidr>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_cidr: The destination CIDR block of the aggregate route.
               
               > **NOTE:**   The following CIDR blocks are not supported:
               
               > **NOTE:** *   CIDR blocks that start with 0 or 100.64.
               
               > **NOTE:** *   Multicast CIDR blocks, including 224.0.0.1 to 239.255.255.254.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_description: The list of propagation ranges of the aggregation route.
               
               > **NOTE:**   You must specify at least one of the following attributes: Aggregation Scope and Aggregate Scope List. We recommend that you specify the latter. The elements in the two attributes cannot be duplicate.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_name: The name of the aggregate route.
               The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_scope: The scope of networks that you want to advertise the aggregate route.
               The valid value is `VPC`, which indicates that the aggregate route is advertised to all VPCs that have associated forwarding correlation with the Enterprise Edition transit router and have route synchronization enabled.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] transit_route_table_aggregation_scope_lists: Aggregation Route Scopes
        :param pulumi.Input[builtins.str] transit_route_table_id: The list of route table IDs of the Enterprise Edition transit router.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TransitRouteTableAggregationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Enterprise Network (CEN) Transit Route Table Aggregation resource.

        For information about Cloud Enterprise Network (CEN) Transit Route Table Aggregation and how to use it, see [What is Transit Route Table Aggregation](https://next.api.alibabacloud.com/document/Cbn/2017-09-12/CreateTransitRouteTableAggregation).

        > **NOTE:** Available since v1.245.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.cen.Instance("example",
            cen_instance_name="tf_example",
            description="an example for cen")
        example_transit_router = alicloud.cen.TransitRouter("example",
            transit_router_name="tf_example",
            cen_id=example.id)
        example_transit_router_route_table = alicloud.cen.TransitRouterRouteTable("example", transit_router_id=example_transit_router.transit_router_id)
        example_transit_route_table_aggregation = alicloud.cen.TransitRouteTableAggregation("example",
            transit_route_table_id=example_transit_router_route_table.transit_router_route_table_id,
            transit_route_table_aggregation_cidr="10.0.0.0/8",
            transit_route_table_aggregation_scope="VPC",
            transit_route_table_aggregation_name="tf_example",
            transit_route_table_aggregation_description="tf_example")
        ```

        ## Import

        Cloud Enterprise Network (CEN) Transit Route Table Aggregation can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cen/transitRouteTableAggregation:TransitRouteTableAggregation example <transit_route_table_id>#<transit_route_table_aggregation_cidr>
        ```

        :param str resource_name: The name of the resource.
        :param TransitRouteTableAggregationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TransitRouteTableAggregationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 transit_route_table_aggregation_cidr: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_description: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_scope: Optional[pulumi.Input[builtins.str]] = None,
                 transit_route_table_aggregation_scope_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 transit_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TransitRouteTableAggregationArgs.__new__(TransitRouteTableAggregationArgs)

            if transit_route_table_aggregation_cidr is None and not opts.urn:
                raise TypeError("Missing required property 'transit_route_table_aggregation_cidr'")
            __props__.__dict__["transit_route_table_aggregation_cidr"] = transit_route_table_aggregation_cidr
            __props__.__dict__["transit_route_table_aggregation_description"] = transit_route_table_aggregation_description
            __props__.__dict__["transit_route_table_aggregation_name"] = transit_route_table_aggregation_name
            __props__.__dict__["transit_route_table_aggregation_scope"] = transit_route_table_aggregation_scope
            __props__.__dict__["transit_route_table_aggregation_scope_lists"] = transit_route_table_aggregation_scope_lists
            if transit_route_table_id is None and not opts.urn:
                raise TypeError("Missing required property 'transit_route_table_id'")
            __props__.__dict__["transit_route_table_id"] = transit_route_table_id
            __props__.__dict__["status"] = None
        super(TransitRouteTableAggregation, __self__).__init__(
            'alicloud:cen/transitRouteTableAggregation:TransitRouteTableAggregation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            transit_route_table_aggregation_cidr: Optional[pulumi.Input[builtins.str]] = None,
            transit_route_table_aggregation_description: Optional[pulumi.Input[builtins.str]] = None,
            transit_route_table_aggregation_name: Optional[pulumi.Input[builtins.str]] = None,
            transit_route_table_aggregation_scope: Optional[pulumi.Input[builtins.str]] = None,
            transit_route_table_aggregation_scope_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            transit_route_table_id: Optional[pulumi.Input[builtins.str]] = None) -> 'TransitRouteTableAggregation':
        """
        Get an existing TransitRouteTableAggregation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] status: The status of the resource
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_cidr: The destination CIDR block of the aggregate route.
               
               > **NOTE:**   The following CIDR blocks are not supported:
               
               > **NOTE:** *   CIDR blocks that start with 0 or 100.64.
               
               > **NOTE:** *   Multicast CIDR blocks, including 224.0.0.1 to 239.255.255.254.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_description: The list of propagation ranges of the aggregation route.
               
               > **NOTE:**   You must specify at least one of the following attributes: Aggregation Scope and Aggregate Scope List. We recommend that you specify the latter. The elements in the two attributes cannot be duplicate.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_name: The name of the aggregate route.
               The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        :param pulumi.Input[builtins.str] transit_route_table_aggregation_scope: The scope of networks that you want to advertise the aggregate route.
               The valid value is `VPC`, which indicates that the aggregate route is advertised to all VPCs that have associated forwarding correlation with the Enterprise Edition transit router and have route synchronization enabled.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] transit_route_table_aggregation_scope_lists: Aggregation Route Scopes
        :param pulumi.Input[builtins.str] transit_route_table_id: The list of route table IDs of the Enterprise Edition transit router.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TransitRouteTableAggregationState.__new__(_TransitRouteTableAggregationState)

        __props__.__dict__["status"] = status
        __props__.__dict__["transit_route_table_aggregation_cidr"] = transit_route_table_aggregation_cidr
        __props__.__dict__["transit_route_table_aggregation_description"] = transit_route_table_aggregation_description
        __props__.__dict__["transit_route_table_aggregation_name"] = transit_route_table_aggregation_name
        __props__.__dict__["transit_route_table_aggregation_scope"] = transit_route_table_aggregation_scope
        __props__.__dict__["transit_route_table_aggregation_scope_lists"] = transit_route_table_aggregation_scope_lists
        __props__.__dict__["transit_route_table_id"] = transit_route_table_id
        return TransitRouteTableAggregation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="transitRouteTableAggregationCidr")
    def transit_route_table_aggregation_cidr(self) -> pulumi.Output[builtins.str]:
        """
        The destination CIDR block of the aggregate route.

        > **NOTE:**   The following CIDR blocks are not supported:

        > **NOTE:** *   CIDR blocks that start with 0 or 100.64.

        > **NOTE:** *   Multicast CIDR blocks, including 224.0.0.1 to 239.255.255.254.
        """
        return pulumi.get(self, "transit_route_table_aggregation_cidr")

    @property
    @pulumi.getter(name="transitRouteTableAggregationDescription")
    def transit_route_table_aggregation_description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The list of propagation ranges of the aggregation route.

        > **NOTE:**   You must specify at least one of the following attributes: Aggregation Scope and Aggregate Scope List. We recommend that you specify the latter. The elements in the two attributes cannot be duplicate.
        """
        return pulumi.get(self, "transit_route_table_aggregation_description")

    @property
    @pulumi.getter(name="transitRouteTableAggregationName")
    def transit_route_table_aggregation_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The name of the aggregate route.
        The name can be empty or 1 to 128 characters in length, and cannot start with http:// or https://.
        """
        return pulumi.get(self, "transit_route_table_aggregation_name")

    @property
    @pulumi.getter(name="transitRouteTableAggregationScope")
    def transit_route_table_aggregation_scope(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The scope of networks that you want to advertise the aggregate route.
        The valid value is `VPC`, which indicates that the aggregate route is advertised to all VPCs that have associated forwarding correlation with the Enterprise Edition transit router and have route synchronization enabled.
        """
        return pulumi.get(self, "transit_route_table_aggregation_scope")

    @property
    @pulumi.getter(name="transitRouteTableAggregationScopeLists")
    def transit_route_table_aggregation_scope_lists(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Aggregation Route Scopes
        """
        return pulumi.get(self, "transit_route_table_aggregation_scope_lists")

    @property
    @pulumi.getter(name="transitRouteTableId")
    def transit_route_table_id(self) -> pulumi.Output[builtins.str]:
        """
        The list of route table IDs of the Enterprise Edition transit router.
        """
        return pulumi.get(self, "transit_route_table_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AssociatedRuleArgs', 'AssociatedRule']

@pulumi.input_type
class AssociatedRuleArgs:
    def __init__(__self__, *,
                 associated_setting_name: pulumi.Input[builtins.str],
                 status: pulumi.Input[builtins.str],
                 tag_keys: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a AssociatedRule resource.
        :param pulumi.Input[builtins.str] associated_setting_name: The setting name of the associated resource tag rule. For specific values, see the Rule Setting Name column in [Resources that Support Associated Resource Tag Settings](https://www.alibabacloud.com/help/en/resource-management/tag/user-guide/associated-resource-label-settings)
        :param pulumi.Input[builtins.str] status: Whether to enable the associated resource tag rule. Valid values: `Enable`, `Disable`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tag_keys: List of tag keys for the associated resource tag rule.
        """
        pulumi.set(__self__, "associated_setting_name", associated_setting_name)
        pulumi.set(__self__, "status", status)
        if tag_keys is not None:
            pulumi.set(__self__, "tag_keys", tag_keys)

    @property
    @pulumi.getter(name="associatedSettingName")
    def associated_setting_name(self) -> pulumi.Input[builtins.str]:
        """
        The setting name of the associated resource tag rule. For specific values, see the Rule Setting Name column in [Resources that Support Associated Resource Tag Settings](https://www.alibabacloud.com/help/en/resource-management/tag/user-guide/associated-resource-label-settings)
        """
        return pulumi.get(self, "associated_setting_name")

    @associated_setting_name.setter
    def associated_setting_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "associated_setting_name", value)

    @property
    @pulumi.getter
    def status(self) -> pulumi.Input[builtins.str]:
        """
        Whether to enable the associated resource tag rule. Valid values: `Enable`, `Disable`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="tagKeys")
    def tag_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of tag keys for the associated resource tag rule.
        """
        return pulumi.get(self, "tag_keys")

    @tag_keys.setter
    def tag_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tag_keys", value)


@pulumi.input_type
class _AssociatedRuleState:
    def __init__(__self__, *,
                 associated_setting_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tag_keys: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering AssociatedRule resources.
        :param pulumi.Input[builtins.str] associated_setting_name: The setting name of the associated resource tag rule. For specific values, see the Rule Setting Name column in [Resources that Support Associated Resource Tag Settings](https://www.alibabacloud.com/help/en/resource-management/tag/user-guide/associated-resource-label-settings)
        :param pulumi.Input[builtins.str] status: Whether to enable the associated resource tag rule. Valid values: `Enable`, `Disable`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tag_keys: List of tag keys for the associated resource tag rule.
        """
        if associated_setting_name is not None:
            pulumi.set(__self__, "associated_setting_name", associated_setting_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tag_keys is not None:
            pulumi.set(__self__, "tag_keys", tag_keys)

    @property
    @pulumi.getter(name="associatedSettingName")
    def associated_setting_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The setting name of the associated resource tag rule. For specific values, see the Rule Setting Name column in [Resources that Support Associated Resource Tag Settings](https://www.alibabacloud.com/help/en/resource-management/tag/user-guide/associated-resource-label-settings)
        """
        return pulumi.get(self, "associated_setting_name")

    @associated_setting_name.setter
    def associated_setting_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "associated_setting_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Whether to enable the associated resource tag rule. Valid values: `Enable`, `Disable`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="tagKeys")
    def tag_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of tag keys for the associated resource tag rule.
        """
        return pulumi.get(self, "tag_keys")

    @tag_keys.setter
    def tag_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tag_keys", value)


@pulumi.type_token("alicloud:tag/associatedRule:AssociatedRule")
class AssociatedRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associated_setting_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tag_keys: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        Provides a TAG Associated Rule resource.

        For information about TAG Associated Rule and how to use it, see [What is Associated Rule](https://www.alibabacloud.com/help/en/resource-management/tag/developer-reference/api-tag-2018-08-28-createassociatedresourcerules).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.tag.AssociatedRule("default",
            status="Enable",
            associated_setting_name="rule:AttachEni-DetachEni-TagInstance:Ecs-Instance:Ecs-Eni",
            tag_keys=["user"])
        ```

        ## Import

        TAG Associated Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:tag/associatedRule:AssociatedRule example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] associated_setting_name: The setting name of the associated resource tag rule. For specific values, see the Rule Setting Name column in [Resources that Support Associated Resource Tag Settings](https://www.alibabacloud.com/help/en/resource-management/tag/user-guide/associated-resource-label-settings)
        :param pulumi.Input[builtins.str] status: Whether to enable the associated resource tag rule. Valid values: `Enable`, `Disable`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tag_keys: List of tag keys for the associated resource tag rule.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AssociatedRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a TAG Associated Rule resource.

        For information about TAG Associated Rule and how to use it, see [What is Associated Rule](https://www.alibabacloud.com/help/en/resource-management/tag/developer-reference/api-tag-2018-08-28-createassociatedresourcerules).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.tag.AssociatedRule("default",
            status="Enable",
            associated_setting_name="rule:AttachEni-DetachEni-TagInstance:Ecs-Instance:Ecs-Eni",
            tag_keys=["user"])
        ```

        ## Import

        TAG Associated Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:tag/associatedRule:AssociatedRule example <id>
        ```

        :param str resource_name: The name of the resource.
        :param AssociatedRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AssociatedRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associated_setting_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tag_keys: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AssociatedRuleArgs.__new__(AssociatedRuleArgs)

            if associated_setting_name is None and not opts.urn:
                raise TypeError("Missing required property 'associated_setting_name'")
            __props__.__dict__["associated_setting_name"] = associated_setting_name
            if status is None and not opts.urn:
                raise TypeError("Missing required property 'status'")
            __props__.__dict__["status"] = status
            __props__.__dict__["tag_keys"] = tag_keys
        super(AssociatedRule, __self__).__init__(
            'alicloud:tag/associatedRule:AssociatedRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            associated_setting_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tag_keys: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'AssociatedRule':
        """
        Get an existing AssociatedRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] associated_setting_name: The setting name of the associated resource tag rule. For specific values, see the Rule Setting Name column in [Resources that Support Associated Resource Tag Settings](https://www.alibabacloud.com/help/en/resource-management/tag/user-guide/associated-resource-label-settings)
        :param pulumi.Input[builtins.str] status: Whether to enable the associated resource tag rule. Valid values: `Enable`, `Disable`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] tag_keys: List of tag keys for the associated resource tag rule.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AssociatedRuleState.__new__(_AssociatedRuleState)

        __props__.__dict__["associated_setting_name"] = associated_setting_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tag_keys"] = tag_keys
        return AssociatedRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="associatedSettingName")
    def associated_setting_name(self) -> pulumi.Output[builtins.str]:
        """
        The setting name of the associated resource tag rule. For specific values, see the Rule Setting Name column in [Resources that Support Associated Resource Tag Settings](https://www.alibabacloud.com/help/en/resource-management/tag/user-guide/associated-resource-label-settings)
        """
        return pulumi.get(self, "associated_setting_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Whether to enable the associated resource tag rule. Valid values: `Enable`, `Disable`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="tagKeys")
    def tag_keys(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        List of tag keys for the associated resource tag rule.
        """
        return pulumi.get(self, "tag_keys")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AccessConfigurationPermissionPolicyArgs',
    'AccessConfigurationPermissionPolicyArgsDict',
    'DirectoryLoginPreferenceArgs',
    'DirectoryLoginPreferenceArgsDict',
    'DirectoryMfaAuthenticationSettingInfoArgs',
    'DirectoryMfaAuthenticationSettingInfoArgsDict',
    'DirectoryPasswordPolicyArgs',
    'DirectoryPasswordPolicyArgsDict',
    'DirectorySamlIdentityProviderConfigurationArgs',
    'DirectorySamlIdentityProviderConfigurationArgsDict',
    'DirectorySamlServiceProviderArgs',
    'DirectorySamlServiceProviderArgsDict',
    'DirectoryUserProvisioningConfigurationArgs',
    'DirectoryUserProvisioningConfigurationArgsDict',
]

MYPY = False

if not MYPY:
    class AccessConfigurationPermissionPolicyArgsDict(TypedDict):
        permission_policy_name: pulumi.Input[builtins.str]
        """
        The name of the policy.
        """
        permission_policy_type: pulumi.Input[builtins.str]
        """
        The type of the policy. Valid values: `System`, `Inline`.
        """
        permission_policy_document: NotRequired[pulumi.Input[builtins.str]]
        """
        The configurations of the inline policy. **NOTE:** If `permission_policy_type` is set to `Inline`, `permission_policy_document` is required.
        """
elif False:
    AccessConfigurationPermissionPolicyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class AccessConfigurationPermissionPolicyArgs:
    def __init__(__self__, *,
                 permission_policy_name: pulumi.Input[builtins.str],
                 permission_policy_type: pulumi.Input[builtins.str],
                 permission_policy_document: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] permission_policy_name: The name of the policy.
        :param pulumi.Input[builtins.str] permission_policy_type: The type of the policy. Valid values: `System`, `Inline`.
        :param pulumi.Input[builtins.str] permission_policy_document: The configurations of the inline policy. **NOTE:** If `permission_policy_type` is set to `Inline`, `permission_policy_document` is required.
        """
        pulumi.set(__self__, "permission_policy_name", permission_policy_name)
        pulumi.set(__self__, "permission_policy_type", permission_policy_type)
        if permission_policy_document is not None:
            pulumi.set(__self__, "permission_policy_document", permission_policy_document)

    @property
    @pulumi.getter(name="permissionPolicyName")
    def permission_policy_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the policy.
        """
        return pulumi.get(self, "permission_policy_name")

    @permission_policy_name.setter
    def permission_policy_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "permission_policy_name", value)

    @property
    @pulumi.getter(name="permissionPolicyType")
    def permission_policy_type(self) -> pulumi.Input[builtins.str]:
        """
        The type of the policy. Valid values: `System`, `Inline`.
        """
        return pulumi.get(self, "permission_policy_type")

    @permission_policy_type.setter
    def permission_policy_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "permission_policy_type", value)

    @property
    @pulumi.getter(name="permissionPolicyDocument")
    def permission_policy_document(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The configurations of the inline policy. **NOTE:** If `permission_policy_type` is set to `Inline`, `permission_policy_document` is required.
        """
        return pulumi.get(self, "permission_policy_document")

    @permission_policy_document.setter
    def permission_policy_document(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "permission_policy_document", value)


if not MYPY:
    class DirectoryLoginPreferenceArgsDict(TypedDict):
        allow_user_to_get_credentials: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether the user can obtain the program access credential in the portal after logging in.
        """
        login_network_masks: NotRequired[pulumi.Input[builtins.str]]
        """
        IP address whitelist
        """
elif False:
    DirectoryLoginPreferenceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DirectoryLoginPreferenceArgs:
    def __init__(__self__, *,
                 allow_user_to_get_credentials: Optional[pulumi.Input[builtins.bool]] = None,
                 login_network_masks: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.bool] allow_user_to_get_credentials: Whether the user can obtain the program access credential in the portal after logging in.
        :param pulumi.Input[builtins.str] login_network_masks: IP address whitelist
        """
        if allow_user_to_get_credentials is not None:
            pulumi.set(__self__, "allow_user_to_get_credentials", allow_user_to_get_credentials)
        if login_network_masks is not None:
            pulumi.set(__self__, "login_network_masks", login_network_masks)

    @property
    @pulumi.getter(name="allowUserToGetCredentials")
    def allow_user_to_get_credentials(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the user can obtain the program access credential in the portal after logging in.
        """
        return pulumi.get(self, "allow_user_to_get_credentials")

    @allow_user_to_get_credentials.setter
    def allow_user_to_get_credentials(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "allow_user_to_get_credentials", value)

    @property
    @pulumi.getter(name="loginNetworkMasks")
    def login_network_masks(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP address whitelist
        """
        return pulumi.get(self, "login_network_masks")

    @login_network_masks.setter
    def login_network_masks(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "login_network_masks", value)


if not MYPY:
    class DirectoryMfaAuthenticationSettingInfoArgsDict(TypedDict):
        mfa_authentication_advance_settings: NotRequired[pulumi.Input[builtins.str]]
        """
        Global MFA validation policy
        """
        operation_for_risk_login: NotRequired[pulumi.Input[builtins.str]]
        """
        MFA verification policy for abnormal logon.
        """
elif False:
    DirectoryMfaAuthenticationSettingInfoArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DirectoryMfaAuthenticationSettingInfoArgs:
    def __init__(__self__, *,
                 mfa_authentication_advance_settings: Optional[pulumi.Input[builtins.str]] = None,
                 operation_for_risk_login: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] mfa_authentication_advance_settings: Global MFA validation policy
        :param pulumi.Input[builtins.str] operation_for_risk_login: MFA verification policy for abnormal logon.
        """
        if mfa_authentication_advance_settings is not None:
            pulumi.set(__self__, "mfa_authentication_advance_settings", mfa_authentication_advance_settings)
        if operation_for_risk_login is not None:
            pulumi.set(__self__, "operation_for_risk_login", operation_for_risk_login)

    @property
    @pulumi.getter(name="mfaAuthenticationAdvanceSettings")
    def mfa_authentication_advance_settings(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Global MFA validation policy
        """
        return pulumi.get(self, "mfa_authentication_advance_settings")

    @mfa_authentication_advance_settings.setter
    def mfa_authentication_advance_settings(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mfa_authentication_advance_settings", value)

    @property
    @pulumi.getter(name="operationForRiskLogin")
    def operation_for_risk_login(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        MFA verification policy for abnormal logon.
        """
        return pulumi.get(self, "operation_for_risk_login")

    @operation_for_risk_login.setter
    def operation_for_risk_login(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "operation_for_risk_login", value)


if not MYPY:
    class DirectoryPasswordPolicyArgsDict(TypedDict):
        hard_expire: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether to restrict login after Password Expiration
        """
        max_login_attempts: NotRequired[pulumi.Input[builtins.int]]
        """
        Number of password retries.
        """
        max_password_age: NotRequired[pulumi.Input[builtins.int]]
        """
        Password validity period.
        """
        max_password_length: NotRequired[pulumi.Input[builtins.int]]
        """
        Maximum password length.
        """
        min_password_different_chars: NotRequired[pulumi.Input[builtins.int]]
        """
        The minimum number of different characters in a password.
        """
        min_password_length: NotRequired[pulumi.Input[builtins.int]]
        """
        Minimum password length.
        """
        password_not_contain_username: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether the user name is not allowed in the password.
        """
        password_reuse_prevention: NotRequired[pulumi.Input[builtins.int]]
        """
        Historical password check policy.
        """
        require_lower_case_chars: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether lowercase letters are required in the password.
        """
        require_numbers: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether numbers are required in the password.
        """
        require_symbols: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether symbols are required in the password.
        """
        require_upper_case_chars: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether uppercase letters are required in the password.
        """
elif False:
    DirectoryPasswordPolicyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DirectoryPasswordPolicyArgs:
    def __init__(__self__, *,
                 hard_expire: Optional[pulumi.Input[builtins.bool]] = None,
                 max_login_attempts: Optional[pulumi.Input[builtins.int]] = None,
                 max_password_age: Optional[pulumi.Input[builtins.int]] = None,
                 max_password_length: Optional[pulumi.Input[builtins.int]] = None,
                 min_password_different_chars: Optional[pulumi.Input[builtins.int]] = None,
                 min_password_length: Optional[pulumi.Input[builtins.int]] = None,
                 password_not_contain_username: Optional[pulumi.Input[builtins.bool]] = None,
                 password_reuse_prevention: Optional[pulumi.Input[builtins.int]] = None,
                 require_lower_case_chars: Optional[pulumi.Input[builtins.bool]] = None,
                 require_numbers: Optional[pulumi.Input[builtins.bool]] = None,
                 require_symbols: Optional[pulumi.Input[builtins.bool]] = None,
                 require_upper_case_chars: Optional[pulumi.Input[builtins.bool]] = None):
        """
        :param pulumi.Input[builtins.bool] hard_expire: Whether to restrict login after Password Expiration
        :param pulumi.Input[builtins.int] max_login_attempts: Number of password retries.
        :param pulumi.Input[builtins.int] max_password_age: Password validity period.
        :param pulumi.Input[builtins.int] max_password_length: Maximum password length.
        :param pulumi.Input[builtins.int] min_password_different_chars: The minimum number of different characters in a password.
        :param pulumi.Input[builtins.int] min_password_length: Minimum password length.
        :param pulumi.Input[builtins.bool] password_not_contain_username: Whether the user name is not allowed in the password.
        :param pulumi.Input[builtins.int] password_reuse_prevention: Historical password check policy.
        :param pulumi.Input[builtins.bool] require_lower_case_chars: Whether lowercase letters are required in the password.
        :param pulumi.Input[builtins.bool] require_numbers: Whether numbers are required in the password.
        :param pulumi.Input[builtins.bool] require_symbols: Whether symbols are required in the password.
        :param pulumi.Input[builtins.bool] require_upper_case_chars: Whether uppercase letters are required in the password.
        """
        if hard_expire is not None:
            pulumi.set(__self__, "hard_expire", hard_expire)
        if max_login_attempts is not None:
            pulumi.set(__self__, "max_login_attempts", max_login_attempts)
        if max_password_age is not None:
            pulumi.set(__self__, "max_password_age", max_password_age)
        if max_password_length is not None:
            pulumi.set(__self__, "max_password_length", max_password_length)
        if min_password_different_chars is not None:
            pulumi.set(__self__, "min_password_different_chars", min_password_different_chars)
        if min_password_length is not None:
            pulumi.set(__self__, "min_password_length", min_password_length)
        if password_not_contain_username is not None:
            pulumi.set(__self__, "password_not_contain_username", password_not_contain_username)
        if password_reuse_prevention is not None:
            pulumi.set(__self__, "password_reuse_prevention", password_reuse_prevention)
        if require_lower_case_chars is not None:
            pulumi.set(__self__, "require_lower_case_chars", require_lower_case_chars)
        if require_numbers is not None:
            pulumi.set(__self__, "require_numbers", require_numbers)
        if require_symbols is not None:
            pulumi.set(__self__, "require_symbols", require_symbols)
        if require_upper_case_chars is not None:
            pulumi.set(__self__, "require_upper_case_chars", require_upper_case_chars)

    @property
    @pulumi.getter(name="hardExpire")
    def hard_expire(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether to restrict login after Password Expiration
        """
        return pulumi.get(self, "hard_expire")

    @hard_expire.setter
    def hard_expire(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "hard_expire", value)

    @property
    @pulumi.getter(name="maxLoginAttempts")
    def max_login_attempts(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of password retries.
        """
        return pulumi.get(self, "max_login_attempts")

    @max_login_attempts.setter
    def max_login_attempts(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_login_attempts", value)

    @property
    @pulumi.getter(name="maxPasswordAge")
    def max_password_age(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Password validity period.
        """
        return pulumi.get(self, "max_password_age")

    @max_password_age.setter
    def max_password_age(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_password_age", value)

    @property
    @pulumi.getter(name="maxPasswordLength")
    def max_password_length(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Maximum password length.
        """
        return pulumi.get(self, "max_password_length")

    @max_password_length.setter
    def max_password_length(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_password_length", value)

    @property
    @pulumi.getter(name="minPasswordDifferentChars")
    def min_password_different_chars(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The minimum number of different characters in a password.
        """
        return pulumi.get(self, "min_password_different_chars")

    @min_password_different_chars.setter
    def min_password_different_chars(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "min_password_different_chars", value)

    @property
    @pulumi.getter(name="minPasswordLength")
    def min_password_length(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Minimum password length.
        """
        return pulumi.get(self, "min_password_length")

    @min_password_length.setter
    def min_password_length(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "min_password_length", value)

    @property
    @pulumi.getter(name="passwordNotContainUsername")
    def password_not_contain_username(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the user name is not allowed in the password.
        """
        return pulumi.get(self, "password_not_contain_username")

    @password_not_contain_username.setter
    def password_not_contain_username(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "password_not_contain_username", value)

    @property
    @pulumi.getter(name="passwordReusePrevention")
    def password_reuse_prevention(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Historical password check policy.
        """
        return pulumi.get(self, "password_reuse_prevention")

    @password_reuse_prevention.setter
    def password_reuse_prevention(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "password_reuse_prevention", value)

    @property
    @pulumi.getter(name="requireLowerCaseChars")
    def require_lower_case_chars(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether lowercase letters are required in the password.
        """
        return pulumi.get(self, "require_lower_case_chars")

    @require_lower_case_chars.setter
    def require_lower_case_chars(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "require_lower_case_chars", value)

    @property
    @pulumi.getter(name="requireNumbers")
    def require_numbers(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether numbers are required in the password.
        """
        return pulumi.get(self, "require_numbers")

    @require_numbers.setter
    def require_numbers(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "require_numbers", value)

    @property
    @pulumi.getter(name="requireSymbols")
    def require_symbols(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether symbols are required in the password.
        """
        return pulumi.get(self, "require_symbols")

    @require_symbols.setter
    def require_symbols(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "require_symbols", value)

    @property
    @pulumi.getter(name="requireUpperCaseChars")
    def require_upper_case_chars(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether uppercase letters are required in the password.
        """
        return pulumi.get(self, "require_upper_case_chars")

    @require_upper_case_chars.setter
    def require_upper_case_chars(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "require_upper_case_chars", value)


if not MYPY:
    class DirectorySamlIdentityProviderConfigurationArgsDict(TypedDict):
        binding_type: NotRequired[pulumi.Input[builtins.str]]
        """
        The Binding method for initiating a SAML request.
        """
        certificate_ids: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        Certificate ID list
        """
        create_time: NotRequired[pulumi.Input[builtins.str]]
        """
        CreateTime
        """
        encoded_metadata_document: NotRequired[pulumi.Input[builtins.str]]
        """
        EncodedMetadataDocument
        """
        entity_id: NotRequired[pulumi.Input[builtins.str]]
        """
        EntityId
        """
        login_url: NotRequired[pulumi.Input[builtins.str]]
        """
        LoginUrl
        """
        sso_status: NotRequired[pulumi.Input[builtins.str]]
        """
        SSOStatus
        """
        update_time: NotRequired[pulumi.Input[builtins.str]]
        """
        UpdateTime
        """
        want_request_signed: NotRequired[pulumi.Input[builtins.bool]]
        """
        SP Request whether the signature is required
        """
elif False:
    DirectorySamlIdentityProviderConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DirectorySamlIdentityProviderConfigurationArgs:
    def __init__(__self__, *,
                 binding_type: Optional[pulumi.Input[builtins.str]] = None,
                 certificate_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 encoded_metadata_document: Optional[pulumi.Input[builtins.str]] = None,
                 entity_id: Optional[pulumi.Input[builtins.str]] = None,
                 login_url: Optional[pulumi.Input[builtins.str]] = None,
                 sso_status: Optional[pulumi.Input[builtins.str]] = None,
                 update_time: Optional[pulumi.Input[builtins.str]] = None,
                 want_request_signed: Optional[pulumi.Input[builtins.bool]] = None):
        """
        :param pulumi.Input[builtins.str] binding_type: The Binding method for initiating a SAML request.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] certificate_ids: Certificate ID list
        :param pulumi.Input[builtins.str] create_time: CreateTime
        :param pulumi.Input[builtins.str] encoded_metadata_document: EncodedMetadataDocument
        :param pulumi.Input[builtins.str] entity_id: EntityId
        :param pulumi.Input[builtins.str] login_url: LoginUrl
        :param pulumi.Input[builtins.str] sso_status: SSOStatus
        :param pulumi.Input[builtins.str] update_time: UpdateTime
        :param pulumi.Input[builtins.bool] want_request_signed: SP Request whether the signature is required
        """
        if binding_type is not None:
            pulumi.set(__self__, "binding_type", binding_type)
        if certificate_ids is not None:
            pulumi.set(__self__, "certificate_ids", certificate_ids)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if encoded_metadata_document is not None:
            pulumi.set(__self__, "encoded_metadata_document", encoded_metadata_document)
        if entity_id is not None:
            pulumi.set(__self__, "entity_id", entity_id)
        if login_url is not None:
            pulumi.set(__self__, "login_url", login_url)
        if sso_status is not None:
            pulumi.set(__self__, "sso_status", sso_status)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if want_request_signed is not None:
            pulumi.set(__self__, "want_request_signed", want_request_signed)

    @property
    @pulumi.getter(name="bindingType")
    def binding_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Binding method for initiating a SAML request.
        """
        return pulumi.get(self, "binding_type")

    @binding_type.setter
    def binding_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "binding_type", value)

    @property
    @pulumi.getter(name="certificateIds")
    def certificate_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Certificate ID list
        """
        return pulumi.get(self, "certificate_ids")

    @certificate_ids.setter
    def certificate_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "certificate_ids", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CreateTime
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="encodedMetadataDocument")
    def encoded_metadata_document(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        EncodedMetadataDocument
        """
        return pulumi.get(self, "encoded_metadata_document")

    @encoded_metadata_document.setter
    def encoded_metadata_document(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "encoded_metadata_document", value)

    @property
    @pulumi.getter(name="entityId")
    def entity_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        EntityId
        """
        return pulumi.get(self, "entity_id")

    @entity_id.setter
    def entity_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "entity_id", value)

    @property
    @pulumi.getter(name="loginUrl")
    def login_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        LoginUrl
        """
        return pulumi.get(self, "login_url")

    @login_url.setter
    def login_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "login_url", value)

    @property
    @pulumi.getter(name="ssoStatus")
    def sso_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SSOStatus
        """
        return pulumi.get(self, "sso_status")

    @sso_status.setter
    def sso_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sso_status", value)

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        UpdateTime
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "update_time", value)

    @property
    @pulumi.getter(name="wantRequestSigned")
    def want_request_signed(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        SP Request whether the signature is required
        """
        return pulumi.get(self, "want_request_signed")

    @want_request_signed.setter
    def want_request_signed(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "want_request_signed", value)


if not MYPY:
    class DirectorySamlServiceProviderArgsDict(TypedDict):
        acs_url: NotRequired[pulumi.Input[builtins.str]]
        """
        ACS URL of SP.
        """
        authn_sign_algo: NotRequired[pulumi.Input[builtins.str]]
        """
        Signature algorithms supported by AuthNRequest
        """
        certificate_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Type of certificate used for signing in the SSO process
        """
        encoded_metadata_document: NotRequired[pulumi.Input[builtins.str]]
        """
        SP metadata document (Base64 encoding).
        """
        entity_id: NotRequired[pulumi.Input[builtins.str]]
        """
        SP identity.
        """
        support_encrypted_assertion: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether IdP-side encryption of Assertion is supported.
        """
elif False:
    DirectorySamlServiceProviderArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DirectorySamlServiceProviderArgs:
    def __init__(__self__, *,
                 acs_url: Optional[pulumi.Input[builtins.str]] = None,
                 authn_sign_algo: Optional[pulumi.Input[builtins.str]] = None,
                 certificate_type: Optional[pulumi.Input[builtins.str]] = None,
                 encoded_metadata_document: Optional[pulumi.Input[builtins.str]] = None,
                 entity_id: Optional[pulumi.Input[builtins.str]] = None,
                 support_encrypted_assertion: Optional[pulumi.Input[builtins.bool]] = None):
        """
        :param pulumi.Input[builtins.str] acs_url: ACS URL of SP.
        :param pulumi.Input[builtins.str] authn_sign_algo: Signature algorithms supported by AuthNRequest
        :param pulumi.Input[builtins.str] certificate_type: Type of certificate used for signing in the SSO process
        :param pulumi.Input[builtins.str] encoded_metadata_document: SP metadata document (Base64 encoding).
        :param pulumi.Input[builtins.str] entity_id: SP identity.
        :param pulumi.Input[builtins.bool] support_encrypted_assertion: Whether IdP-side encryption of Assertion is supported.
        """
        if acs_url is not None:
            pulumi.set(__self__, "acs_url", acs_url)
        if authn_sign_algo is not None:
            pulumi.set(__self__, "authn_sign_algo", authn_sign_algo)
        if certificate_type is not None:
            pulumi.set(__self__, "certificate_type", certificate_type)
        if encoded_metadata_document is not None:
            pulumi.set(__self__, "encoded_metadata_document", encoded_metadata_document)
        if entity_id is not None:
            pulumi.set(__self__, "entity_id", entity_id)
        if support_encrypted_assertion is not None:
            pulumi.set(__self__, "support_encrypted_assertion", support_encrypted_assertion)

    @property
    @pulumi.getter(name="acsUrl")
    def acs_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ACS URL of SP.
        """
        return pulumi.get(self, "acs_url")

    @acs_url.setter
    def acs_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "acs_url", value)

    @property
    @pulumi.getter(name="authnSignAlgo")
    def authn_sign_algo(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Signature algorithms supported by AuthNRequest
        """
        return pulumi.get(self, "authn_sign_algo")

    @authn_sign_algo.setter
    def authn_sign_algo(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authn_sign_algo", value)

    @property
    @pulumi.getter(name="certificateType")
    def certificate_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of certificate used for signing in the SSO process
        """
        return pulumi.get(self, "certificate_type")

    @certificate_type.setter
    def certificate_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "certificate_type", value)

    @property
    @pulumi.getter(name="encodedMetadataDocument")
    def encoded_metadata_document(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SP metadata document (Base64 encoding).
        """
        return pulumi.get(self, "encoded_metadata_document")

    @encoded_metadata_document.setter
    def encoded_metadata_document(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "encoded_metadata_document", value)

    @property
    @pulumi.getter(name="entityId")
    def entity_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SP identity.
        """
        return pulumi.get(self, "entity_id")

    @entity_id.setter
    def entity_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "entity_id", value)

    @property
    @pulumi.getter(name="supportEncryptedAssertion")
    def support_encrypted_assertion(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether IdP-side encryption of Assertion is supported.
        """
        return pulumi.get(self, "support_encrypted_assertion")

    @support_encrypted_assertion.setter
    def support_encrypted_assertion(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "support_encrypted_assertion", value)


if not MYPY:
    class DirectoryUserProvisioningConfigurationArgsDict(TypedDict):
        default_landing_page: NotRequired[pulumi.Input[builtins.str]]
        """
        The duration of the Session after the user logs in.
        """
        session_duration: NotRequired[pulumi.Input[builtins.str]]
        """
        The duration of the Session after the user logs in.
        """
elif False:
    DirectoryUserProvisioningConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DirectoryUserProvisioningConfigurationArgs:
    def __init__(__self__, *,
                 default_landing_page: Optional[pulumi.Input[builtins.str]] = None,
                 session_duration: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] default_landing_page: The duration of the Session after the user logs in.
        :param pulumi.Input[builtins.str] session_duration: The duration of the Session after the user logs in.
        """
        if default_landing_page is not None:
            pulumi.set(__self__, "default_landing_page", default_landing_page)
        if session_duration is not None:
            pulumi.set(__self__, "session_duration", session_duration)

    @property
    @pulumi.getter(name="defaultLandingPage")
    def default_landing_page(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The duration of the Session after the user logs in.
        """
        return pulumi.get(self, "default_landing_page")

    @default_landing_page.setter
    def default_landing_page(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "default_landing_page", value)

    @property
    @pulumi.getter(name="sessionDuration")
    def session_duration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The duration of the Session after the user logs in.
        """
        return pulumi.get(self, "session_duration")

    @session_duration.setter
    def session_duration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "session_duration", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetZonesResult',
    'AwaitableGetZonesResult',
    'get_zones',
    'get_zones_output',
]

@pulumi.output_type
class GetZonesResult:
    """
    A collection of values returned by getZones.
    """
    def __init__(__self__, file_system_type=None, id=None, output_file=None, zones=None):
        if file_system_type and not isinstance(file_system_type, str):
            raise TypeError("Expected argument 'file_system_type' to be a str")
        pulumi.set(__self__, "file_system_type", file_system_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if zones and not isinstance(zones, list):
            raise TypeError("Expected argument 'zones' to be a list")
        pulumi.set(__self__, "zones", zones)

    @property
    @pulumi.getter(name="fileSystemType")
    def file_system_type(self) -> Optional[builtins.str]:
        return pulumi.get(self, "file_system_type")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def zones(self) -> Sequence['outputs.GetZonesZoneResult']:
        """
        A list of availability zone information collection.
        """
        return pulumi.get(self, "zones")


class AwaitableGetZonesResult(GetZonesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetZonesResult(
            file_system_type=self.file_system_type,
            id=self.id,
            output_file=self.output_file,
            zones=self.zones)


def get_zones(file_system_type: Optional[builtins.str] = None,
              output_file: Optional[builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetZonesResult:
    """
    Provide  a data source to retrieve the type of zone used to create NAS file system.

    > **NOTE:** Available in v1.140.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.nas.get_zones()
    pulumi.export("alicloudNasZonesId", default.zones[0].zone_id)
    ```


    :param builtins.str file_system_type: The type of the file system.  Valid values: `standard`, `extreme`, `cpfs`.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['fileSystemType'] = file_system_type
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:nas/getZones:getZones', __args__, opts=opts, typ=GetZonesResult).value

    return AwaitableGetZonesResult(
        file_system_type=pulumi.get(__ret__, 'file_system_type'),
        id=pulumi.get(__ret__, 'id'),
        output_file=pulumi.get(__ret__, 'output_file'),
        zones=pulumi.get(__ret__, 'zones'))
def get_zones_output(file_system_type: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetZonesResult]:
    """
    Provide  a data source to retrieve the type of zone used to create NAS file system.

    > **NOTE:** Available in v1.140.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default = alicloud.nas.get_zones()
    pulumi.export("alicloudNasZonesId", default.zones[0].zone_id)
    ```


    :param builtins.str file_system_type: The type of the file system.  Valid values: `standard`, `extreme`, `cpfs`.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['fileSystemType'] = file_system_type
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:nas/getZones:getZones', __args__, opts=opts, typ=GetZonesResult)
    return __ret__.apply(lambda __response__: GetZonesResult(
        file_system_type=pulumi.get(__response__, 'file_system_type'),
        id=pulumi.get(__response__, 'id'),
        output_file=pulumi.get(__response__, 'output_file'),
        zones=pulumi.get(__response__, 'zones')))
